AnalyticsAggregation enum

How a metric is aggregated by the analytics backend.

Wire names match the Thesa analytics API aggregation values.

Inheritance
Available extensions

Values

sum → const AnalyticsAggregation
const AnalyticsAggregation('sum')
avg → const AnalyticsAggregation
const AnalyticsAggregation('avg')
count → const AnalyticsAggregation
const AnalyticsAggregation('count')
countDistinct → const AnalyticsAggregation
const AnalyticsAggregation('count_distinct')
gauge → const AnalyticsAggregation
const AnalyticsAggregation('gauge')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireName String
The value sent in API request bodies.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AnalyticsAggregation>
A constant List of the values in this enum, in order of their declaration.