AnalyticsTimeRange class

Time range for analytics queries with optional granularity.

Constructors

AnalyticsTimeRange({required DateTime start, required DateTime end, TimeGranularity? granularity})
const
AnalyticsTimeRange.last7Days()
Last 7 days with daily granularity.
factory
AnalyticsTimeRange.last24Hours()
Last 24 hours with hourly granularity.
factory
AnalyticsTimeRange.last30Days()
Last 30 days with daily granularity.
factory
AnalyticsTimeRange.last90Days()
Last 90 days with weekly granularity.
factory
AnalyticsTimeRange.lastYear()
Last year with monthly granularity.
factory

Properties

duration Duration
Duration of this time range.
no setter
end DateTime
final
granularity TimeGranularity?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
start DateTime
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toQueryParams() Map<String, String>
Query parameters for HTTP requests.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited