DistributionSegment class

A segment in a distribution (pie/donut chart slice).

Constructors

DistributionSegment({required String label, required double value, Color? color})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
percent(double total) double
Percentage of total that this segment represents.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited