MetricValue class

A single KPI metric value (e.g., "Total Payments: 1,234").

Constructors

MetricValue({required String key, required String label, required double value, double? previousValue, String? unit, IconData? icon, MetricTrend? trend})
const

Properties

changePercent double?
Percentage change from previousValue to value.
no setter
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
final
key String
final
label String
final
previousValue double?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
trend MetricTrend?
final
unit String?
Unit hint for formatting: "count", "currency", "percent", "bytes".
final
value double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited