TimeSeries class

A named time series with its data points.

Constructors

TimeSeries({required String key, required String label, required List<TimeSeriesPoint> points, Color? color})
const

Properties

color Color?
final
hashCode int
The hash code for this object.
no setterinherited
key String
final
label String
final
points List<TimeSeriesPoint>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited