PaginatedState<T> class

Holds the state for a paginated list loaded from a gRPC stream.

Constructors

PaginatedState({List<T> items = const [], bool isLoading = false, bool isLoadingMore = false, bool hasMore = true, String? error})
const

Properties

error String?
final
hashCode int
The hash code for this object.
no setterinherited
hasMore bool
final
isLoading bool
final
isLoadingMore bool
final
items List<T>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({List<T>? items, bool? isLoading, bool? isLoadingMore, bool? hasMore, String? error, bool clearError = false}) PaginatedState<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited