AuditContext class

AuditContext captures the full context of an authenticated action: who (user identity claims), when (timestamp), where (device location), and the tenancy context (tenant + partition).

Constructors

AuditContext({required String profileId, String? tenantId, String? partitionId, String? contactId, String? accessId, String? sessionId, String? deviceId, String? displayName, DeviceLocation? location})
const

Properties

accessId String?
final
contactId String?
final
deviceId String?
final
displayLabel String
no setter
displayName String?
final
fullLabel String
no setter
hashCode int
The hash code for this object.
no setterinherited
location DeviceLocation?
final
locationLabel String
no setter
partitionId String?
final
profileId String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionId String?
final
tenantId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() Map<String, String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited