AppLogger class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
Static Methods
-
debug(String message, {Map<String, dynamic>? data})
→ void
-
-
error(String message, {Object? error, StackTrace? stackTrace, Map<String, dynamic>? data})
→ void
-
-
info(String message, {Map<String, dynamic>? data})
→ void
-
-
warning(String message, {Map<String, dynamic>? data})
→ void
-