EntityChipConfig class

Configuration for an entity type displayed as a chip.

Constructors

EntityChipConfig({required IconData icon, required Color color, String routeBuilder(String id)?})
const

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData
final
routeBuilder String Function(String id)?
Builds a route path from the entity ID. Null means non-navigable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited