ChartConfig class
Declarative chart configuration for the dashboard.
Constructors
-
ChartConfig.distribution(String metric, {required String label, required String? groupBy, AnalyticsAggregation aggregation = AnalyticsAggregation.sum, Map<
String, String> ? filters}) -
const
-
ChartConfig.timeSeries(String metric, {required String label, TimeGranularity? granularity, AnalyticsAggregation aggregation = AnalyticsAggregation.sum, Map<
String, String> ? filters}) -
const
Properties
- aggregation → AnalyticsAggregation
-
How the backend aggregates the metric for this chart.
final
-
filters
→ Map<
String, String> ? -
Extra label filters applied alongside the service's base filters.
final
- granularity → TimeGranularity?
-
final
- groupBy → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- label → String
-
final
- metric → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ChartType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited