ChartConfig class

Declarative chart configuration for the dashboard.

Constructors

ChartConfig.distribution(String metric, {required String label, required String groupBy})
const
ChartConfig.timeSeries(String metric, {required String label, TimeGranularity? granularity})
const

Properties

granularity TimeGranularity?
final
groupBy String?
final
hashCode int
The hash code for this object.
no setterinherited
label String
final
metric String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ChartType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited