TableConfig class

Declarative table configuration for the dashboard.

Constructors

TableConfig.topN(String metric, {required String label, int limit = 10})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
label String
final
limit int
final
metric String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited