PaginatedState<T> class
Holds the state for a paginated list loaded from a gRPC stream.
Constructors
Properties
Methods
-
copyWith(
{List< T> ? items, bool? isLoading, bool? isLoadingMore, bool? hasMore, String? error, bool clearError = false}) → PaginatedState<T> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited