DeviceLocation class
DeviceLocation captures the physical and locale context of the device at the time of an action. Embedded into audit trails alongside user identity.
Constructors
- DeviceLocation({double? latitude, double? longitude, double? accuracy, String? country, String? countryCode, String? administrativeArea, String? subAdministrativeArea, String? locality, String? subLocality, String? postalCode, String? timezone, String? language, String? locale, String? platformName, String? error})
-
const
Properties
- accuracy → double?
-
final
- administrativeArea → String?
-
final
- country → String?
-
final
- countryCode → String?
-
final
- displayLabel → String
-
Human-readable location summary, e.g. "Nairobi, Kenya"
no setter
- error → String?
-
final
- hasAddress → bool
-
no setter
- hasCoordinates → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- language → String?
-
final
- latitude → double?
-
final
- locale → String?
-
final
- locality → String?
-
final
- longitude → double?
-
final
- platformName → String?
-
final
- postalCode → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- subAdministrativeArea → String?
-
final
- subLocality → String?
-
final
- timezone → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, String> - Serializes to a map for embedding in audit trail properties.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited