TenancyContext class
The active tenancy context for the current user session.
Tracks the selected organization and branch within the user's partition.
- Inheritance
-
- Object
- ChangeNotifier
- TenancyContext
Constructors
Properties
- branchId → String
-
no setter
- branchName → String
-
no setter
-
no setter
- canSelectBranch → bool
-
no setter
- canSelectOrganization → bool
-
no setter
- hasBranch → bool
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasOrganization → bool
-
no setter
- hasPartition → bool
-
no setter
- loginLevel → LoginLevel
-
no setter
- organizationId → String
-
no setter
- organizationName → String
-
no setter
- partitionId → String
-
no setter
- partitionName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clear(
) → void -
dispose(
) → void -
Discards any resources used by the object.
inherited
-
initializeFromLogin(
LoginLevel level, {String? partitionId, String? partitionName, String? orgId, String? orgName, String? branchId, String? branchName}) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
selectBranch(
String id, String name, {String? partitionId, String? partitionName}) → void -
selectOrganization(
String id, String name, {String? partitionId, String? partitionName}) → void -
selectPartition(
String id, String name) → void -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited