DialogField class
Field definition for showEditDialog.
Constructors
-
DialogField({required String key, required String label, String? hint, String initialValue = '', DialogFieldType type = DialogFieldType.text, List<
String> options = const [], int maxLines = 1, bool required = false}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hint → String?
-
final
- initialValue → String
-
final
- key → String
-
final
- label → String
-
final
- maxLines → int
-
final
-
options
→ List<
String> -
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → DialogFieldType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited